package net.p0f.openshift.metrics.rest;

import java.net.InetAddress;
import java.net.UnknownHostException;
import java.util.Random;
import java.util.logging.Logger;

import io.micrometer.core.annotation.Timed;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.Path;

@Path("/")
@ApplicationScoped
public class HelloWorld {
    private static final Logger LOG = Logger.getLogger(HelloWorld.class.getName());

    @Timed(value = "hello", histogram = true, percentiles = {.5, .75, .9, .95, .96, .97, .98, .99, .995, .999, 1.0},
            description = "timings for saying hello")
    @GET
    @Path("/hello")
    public String sayHello() {
        String hostname = "unknown host";
        try {
            hostname =  InetAddress.getLocalHost().getHostName();
        } catch (UnknownHostException uhe) {
            LOG.warning("Can not figure out my hostname, using " + hostname);
        }

        long waittime = new Random().nextLong(500);
        LOG.info("Waiting for " + waittime + " ms...");
        try {
            Thread.sleep(waittime);
        } catch (InterruptedException ie) {
            LOG.warning("Got interrupted during sleep.");
        }
        return "Hello from " + hostname + "! Wait time was " + waittime + " ms.";
    }
}
